===========
Connections
===========

This section describes various ways to communicate with network devices in order to pull configuration information.


.. toctree::
   :maxdepth: 3

   CLI_Connections/index
   REST_Connections/index